import com.micronova.math.*;
import com.micronova.*;
import com.micronova.util.*;

import netscape.util.*;

import java.io.*;

// This is a linearly interpolated cumulative normal function
// implemented as a LinearSegmentedCurve.  To save space, only
// the positive side points are given, and getValueOf is overridden
// to compute the values for negative inputs.

class CumulativeNormal2 extends LinearSegmentedCurve
{
    CumulativeNormal2()
    {
        super();

        // here are the points

        addElement(new CurvePoint(0.0, 0.5));
        addElement(new CurvePoint(0.01, 0.503989356315));
        addElement(new CurvePoint(0.02, 0.507978313717));
        addElement(new CurvePoint(0.03, 0.511966473414));
        addElement(new CurvePoint(0.04, 0.515953436853));
        addElement(new CurvePoint(0.05, 0.519938805838));
        addElement(new CurvePoint(0.06, 0.523922182654));
        addElement(new CurvePoint(0.07, 0.527903170181));
        addElement(new CurvePoint(0.08, 0.531881372014));
        addElement(new CurvePoint(0.09, 0.535856392585));
        addElement(new CurvePoint(0.1, 0.539827837277));
        addElement(new CurvePoint(0.11, 0.543795312542));
        addElement(new CurvePoint(0.12, 0.547758426021));
        addElement(new CurvePoint(0.13, 0.551716786655));
        addElement(new CurvePoint(0.14, 0.555670004806));
        addElement(new CurvePoint(0.15, 0.55961769237));
        addElement(new CurvePoint(0.16, 0.563559462891));
        addElement(new CurvePoint(0.17, 0.567494931675));
        addElement(new CurvePoint(0.18, 0.571423715901));
        addElement(new CurvePoint(0.19, 0.575345434735));
        addElement(new CurvePoint(0.2, 0.579259709439));
        addElement(new CurvePoint(0.21, 0.583166163482));
        addElement(new CurvePoint(0.22, 0.587064422648));
        addElement(new CurvePoint(0.23, 0.590954115142));
        addElement(new CurvePoint(0.24, 0.594834871698));
        addElement(new CurvePoint(0.25, 0.598706325683));
        addElement(new CurvePoint(0.26, 0.602568113202));
        addElement(new CurvePoint(0.27, 0.606419873198));
        addElement(new CurvePoint(0.28, 0.610261247556));
        addElement(new CurvePoint(0.29, 0.614091881199));
        addElement(new CurvePoint(0.3, 0.617911422189));
        addElement(new CurvePoint(0.31, 0.621719521822));
        addElement(new CurvePoint(0.32, 0.625515834723));
        addElement(new CurvePoint(0.33, 0.629300018941));
        addElement(new CurvePoint(0.34, 0.633071736036));
        addElement(new CurvePoint(0.35, 0.636830651176));
        addElement(new CurvePoint(0.36, 0.640576433218));
        addElement(new CurvePoint(0.37, 0.644308754801));
        addElement(new CurvePoint(0.38, 0.648027292424));
        addElement(new CurvePoint(0.39, 0.651731726536));
        addElement(new CurvePoint(0.4, 0.65542174161));
        addElement(new CurvePoint(0.41, 0.659097026228));
        addElement(new CurvePoint(0.42, 0.662757273152));
        addElement(new CurvePoint(0.43, 0.666402179405));
        addElement(new CurvePoint(0.44, 0.670031446339));
        addElement(new CurvePoint(0.45, 0.673644779712));
        addElement(new CurvePoint(0.46, 0.67724188975));
        addElement(new CurvePoint(0.47, 0.680822491217));
        addElement(new CurvePoint(0.48, 0.684386303484));
        addElement(new CurvePoint(0.49, 0.687933050583));
        addElement(new CurvePoint(0.5, 0.691462461274));
        addElement(new CurvePoint(0.51, 0.694974269102));
        addElement(new CurvePoint(0.52, 0.698468212453));
        addElement(new CurvePoint(0.53, 0.701944034605));
        addElement(new CurvePoint(0.54, 0.705401483784));
        addElement(new CurvePoint(0.55, 0.708840313212));
        addElement(new CurvePoint(0.56, 0.712260281151));
        addElement(new CurvePoint(0.57, 0.715661150954));
        addElement(new CurvePoint(0.58, 0.719042691101));
        addElement(new CurvePoint(0.59, 0.722404675247));
        addElement(new CurvePoint(0.6, 0.72574688225));
        addElement(new CurvePoint(0.61, 0.729069096217));
        addElement(new CurvePoint(0.62, 0.732371106531));
        addElement(new CurvePoint(0.63, 0.735652707884));
        addElement(new CurvePoint(0.64, 0.738913700307));
        addElement(new CurvePoint(0.65, 0.742153889194));
        addElement(new CurvePoint(0.66, 0.745373085329));
        addElement(new CurvePoint(0.67, 0.748571104905));
        addElement(new CurvePoint(0.68, 0.751747769546));
        addElement(new CurvePoint(0.69, 0.754902906326));
        addElement(new CurvePoint(0.7, 0.758036347777));
        addElement(new CurvePoint(0.71, 0.76114793191));
        addElement(new CurvePoint(0.72, 0.764237502221));
        addElement(new CurvePoint(0.73, 0.767304907699));
        addElement(new CurvePoint(0.74, 0.770350002835));
        addElement(new CurvePoint(0.75, 0.773372647623));
        addElement(new CurvePoint(0.76, 0.776372707562));
        addElement(new CurvePoint(0.77, 0.779350053657));
        addElement(new CurvePoint(0.78, 0.782304562414));
        addElement(new CurvePoint(0.79, 0.785236115836));
        addElement(new CurvePoint(0.8, 0.788144601417));
        addElement(new CurvePoint(0.81, 0.791029912128));
        addElement(new CurvePoint(0.82, 0.793891946414));
        addElement(new CurvePoint(0.83, 0.796730608172));
        addElement(new CurvePoint(0.84, 0.79954580674));
        addElement(new CurvePoint(0.85, 0.802337456877));
        addElement(new CurvePoint(0.86, 0.805105478748));
        addElement(new CurvePoint(0.87, 0.807849797896));
        addElement(new CurvePoint(0.88, 0.810570345223));
        addElement(new CurvePoint(0.89, 0.813267056963));
        addElement(new CurvePoint(0.9, 0.815939874653));
        addElement(new CurvePoint(0.91, 0.818588745108));
        addElement(new CurvePoint(0.92, 0.821213620386));
        addElement(new CurvePoint(0.93, 0.823814457755));
        addElement(new CurvePoint(0.94, 0.826391219661));
        addElement(new CurvePoint(0.95, 0.828943873692));
        addElement(new CurvePoint(0.96, 0.831472392533));
        addElement(new CurvePoint(0.97, 0.833976753936));
        addElement(new CurvePoint(0.98, 0.836456940672));
        addElement(new CurvePoint(0.99, 0.838912940489));
        addElement(new CurvePoint(1.0, 0.841344746069));
        addElement(new CurvePoint(1.01, 0.843752354979));
        addElement(new CurvePoint(1.02, 0.846135769627));
        addElement(new CurvePoint(1.03, 0.848494997212));
        addElement(new CurvePoint(1.04, 0.850830049669));
        addElement(new CurvePoint(1.05, 0.853140943624));
        addElement(new CurvePoint(1.06, 0.855427700336));
        addElement(new CurvePoint(1.07, 0.857690345644));
        addElement(new CurvePoint(1.08, 0.859928909911));
        addElement(new CurvePoint(1.09, 0.862143427968));
        addElement(new CurvePoint(1.1, 0.864333939054));
        addElement(new CurvePoint(1.11, 0.866500486757));
        addElement(new CurvePoint(1.12, 0.868643118957));
        addElement(new CurvePoint(1.13, 0.87076188776));
        addElement(new CurvePoint(1.14, 0.872856849437));
        addElement(new CurvePoint(1.15, 0.874928064363));
        addElement(new CurvePoint(1.16, 0.876975596949));
        addElement(new CurvePoint(1.17, 0.878999515579));
        addElement(new CurvePoint(1.18, 0.880999892545));
        addElement(new CurvePoint(1.19, 0.882976803977));
        addElement(new CurvePoint(1.2, 0.884930329778));
        addElement(new CurvePoint(1.21, 0.886860553556));
        addElement(new CurvePoint(1.22, 0.888767562552));
        addElement(new CurvePoint(1.23, 0.890651447574));
        addElement(new CurvePoint(1.24, 0.892512302925));
        addElement(new CurvePoint(1.25, 0.894350226333));
        addElement(new CurvePoint(1.26, 0.896165318879));
        addElement(new CurvePoint(1.27, 0.897957684925));
        addElement(new CurvePoint(1.28, 0.899727432046));
        addElement(new CurvePoint(1.29, 0.90147467095));
        addElement(new CurvePoint(1.3, 0.903199515414));
        addElement(new CurvePoint(1.31, 0.904902082205));
        addElement(new CurvePoint(1.32, 0.906582491007));
        addElement(new CurvePoint(1.33, 0.90824086435));
        addElement(new CurvePoint(1.34, 0.909877327536));
        addElement(new CurvePoint(1.35, 0.911492008563));
        addElement(new CurvePoint(1.36, 0.913085038053));
        addElement(new CurvePoint(1.37, 0.914656549178));
        addElement(new CurvePoint(1.38, 0.916206677585));
        addElement(new CurvePoint(1.39, 0.917735561322));
        addElement(new CurvePoint(1.4, 0.919243340766));
        addElement(new CurvePoint(1.41, 0.920730158547));
        addElement(new CurvePoint(1.42, 0.922196159473));
        addElement(new CurvePoint(1.43, 0.923641490463));
        addElement(new CurvePoint(1.44, 0.925066300466));
        addElement(new CurvePoint(1.45, 0.92647074039));
        addElement(new CurvePoint(1.46, 0.927854963034));
        addElement(new CurvePoint(1.47, 0.929219123008));
        addElement(new CurvePoint(1.48, 0.930563376667));
        addElement(new CurvePoint(1.49, 0.931887882033));
        addElement(new CurvePoint(1.5, 0.933192798731));
        addElement(new CurvePoint(1.51, 0.934478287911));
        addElement(new CurvePoint(1.52, 0.935744512181));
        addElement(new CurvePoint(1.53, 0.936991635536));
        addElement(new CurvePoint(1.54, 0.938219823288));
        addElement(new CurvePoint(1.55, 0.939429241998));
        addElement(new CurvePoint(1.56, 0.940620059405));
        addElement(new CurvePoint(1.57, 0.941792444361));
        addElement(new CurvePoint(1.58, 0.942946566762));
        addElement(new CurvePoint(1.59, 0.944082597481));
        addElement(new CurvePoint(1.6, 0.9452007083));
        addElement(new CurvePoint(1.61, 0.946301071852));
        addElement(new CurvePoint(1.62, 0.947383861546));
        addElement(new CurvePoint(1.63, 0.94844925151));
        addElement(new CurvePoint(1.64, 0.949497416526));
        addElement(new CurvePoint(1.65, 0.950528531966));
        addElement(new CurvePoint(1.66, 0.951542773733));
        addElement(new CurvePoint(1.67, 0.952540318197));
        addElement(new CurvePoint(1.68, 0.953521342136));
        addElement(new CurvePoint(1.69, 0.954486022678));
        addElement(new CurvePoint(1.7, 0.955434537241));
        addElement(new CurvePoint(1.71, 0.956367063476));
        addElement(new CurvePoint(1.72, 0.957283779209));
        addElement(new CurvePoint(1.73, 0.958184862386));
        addElement(new CurvePoint(1.74, 0.959070491021));
        addElement(new CurvePoint(1.75, 0.959940843136));
        addElement(new CurvePoint(1.76, 0.960796096713));
        addElement(new CurvePoint(1.77, 0.961636429637));
        addElement(new CurvePoint(1.78, 0.962462019651));
        addElement(new CurvePoint(1.79, 0.963273044301));
        addElement(new CurvePoint(1.8, 0.964069680887));
        addElement(new CurvePoint(1.81, 0.964852106416));
        addElement(new CurvePoint(1.82, 0.965620497554));
        addElement(new CurvePoint(1.83, 0.96637503058));
        addElement(new CurvePoint(1.84, 0.967115881341));
        addElement(new CurvePoint(1.85, 0.967843225204));
        addElement(new CurvePoint(1.86, 0.968557237019));
        addElement(new CurvePoint(1.87, 0.969258091071));
        addElement(new CurvePoint(1.88, 0.969945961039));
        addElement(new CurvePoint(1.89, 0.97062101996));
        addElement(new CurvePoint(1.9, 0.971283440184));
        addElement(new CurvePoint(1.91, 0.97193339334));
        addElement(new CurvePoint(1.92, 0.972571050296));
        addElement(new CurvePoint(1.93, 0.973196581123));
        addElement(new CurvePoint(1.94, 0.97381015506));
        addElement(new CurvePoint(1.95, 0.974411940478));
        addElement(new CurvePoint(1.96, 0.975002104852));
        addElement(new CurvePoint(1.97, 0.97558081472));
        addElement(new CurvePoint(1.98, 0.976148235658));
        addElement(new CurvePoint(1.99, 0.97670453225));
        addElement(new CurvePoint(2.0, 0.977249868052));
        addElement(new CurvePoint(2.01, 0.977784405571));
        addElement(new CurvePoint(2.02, 0.978308306232));
        addElement(new CurvePoint(2.03, 0.978821730357));
        addElement(new CurvePoint(2.04, 0.979324837134));
        addElement(new CurvePoint(2.05, 0.979817784594));
        addElement(new CurvePoint(2.06, 0.980300729591));
        addElement(new CurvePoint(2.07, 0.980773827772));
        addElement(new CurvePoint(2.08, 0.981237233565));
        addElement(new CurvePoint(2.09, 0.981691100148));
        addElement(new CurvePoint(2.1, 0.982135579437));
        addElement(new CurvePoint(2.11, 0.982570822062));
        addElement(new CurvePoint(2.12, 0.982996977352));
        addElement(new CurvePoint(2.13, 0.983414193316));
        addElement(new CurvePoint(2.14, 0.983822616628));
        addElement(new CurvePoint(2.15, 0.984222392609));
        addElement(new CurvePoint(2.16, 0.984613665216));
        addElement(new CurvePoint(2.17, 0.984996577026));
        addElement(new CurvePoint(2.18, 0.985371269224));
        addElement(new CurvePoint(2.19, 0.985737881589));
        addElement(new CurvePoint(2.2, 0.986096552487));
        addElement(new CurvePoint(2.21, 0.986447418854));
        addElement(new CurvePoint(2.22, 0.986790616193));
        addElement(new CurvePoint(2.23, 0.987126278561));
        addElement(new CurvePoint(2.24, 0.987454538564));
        addElement(new CurvePoint(2.25, 0.987775527345));
        addElement(new CurvePoint(2.26, 0.988089374581));
        addElement(new CurvePoint(2.27, 0.988396208478));
        addElement(new CurvePoint(2.28, 0.988696155761));
        addElement(new CurvePoint(2.29, 0.988989341676));
        addElement(new CurvePoint(2.3, 0.989275889978));
        addElement(new CurvePoint(2.31, 0.989555922938));
        addElement(new CurvePoint(2.32, 0.989829561331));
        addElement(new CurvePoint(2.33, 0.990096924441));
        addElement(new CurvePoint(2.34, 0.990358130055));
        addElement(new CurvePoint(2.35, 0.990613294465));
        addElement(new CurvePoint(2.36, 0.990862532469));
        addElement(new CurvePoint(2.37, 0.99110595737));
        addElement(new CurvePoint(2.38, 0.991343680974));
        addElement(new CurvePoint(2.39, 0.991575813601));
        addElement(new CurvePoint(2.4, 0.991802464075));
        addElement(new CurvePoint(2.41, 0.992023739739));
        addElement(new CurvePoint(2.42, 0.992239746449));
        addElement(new CurvePoint(2.43, 0.992450588584));
        addElement(new CurvePoint(2.44, 0.992656369045));
        addElement(new CurvePoint(2.45, 0.992857189265));
        addElement(new CurvePoint(2.46, 0.993053149211));
        addElement(new CurvePoint(2.47, 0.993244347393));
        addElement(new CurvePoint(2.48, 0.993430880864));
        addElement(new CurvePoint(2.49, 0.993612845235));
        addElement(new CurvePoint(2.5, 0.993790334674));
        addElement(new CurvePoint(2.51, 0.99396344192));
        addElement(new CurvePoint(2.52, 0.994132258285));
        addElement(new CurvePoint(2.53, 0.994296873667));
        addElement(new CurvePoint(2.54, 0.994457376557));
        addElement(new CurvePoint(2.55, 0.994613854046));
        addElement(new CurvePoint(2.56, 0.994766391836));
        addElement(new CurvePoint(2.57, 0.994915074251));
        addElement(new CurvePoint(2.58, 0.995059984242));
        addElement(new CurvePoint(2.59, 0.995201203403));
        addElement(new CurvePoint(2.6, 0.995338811976));
        addElement(new CurvePoint(2.61, 0.995472888867));
        addElement(new CurvePoint(2.62, 0.995603511652));
        addElement(new CurvePoint(2.63, 0.995730756591));
        addElement(new CurvePoint(2.64, 0.995854698639));
        addElement(new CurvePoint(2.65, 0.995975411457));
        addElement(new CurvePoint(2.66, 0.996092967425));
        addElement(new CurvePoint(2.67, 0.996207437652));
        addElement(new CurvePoint(2.68, 0.996318891991));
        addElement(new CurvePoint(2.69, 0.996427399048));
        addElement(new CurvePoint(2.7, 0.996533026197));
        addElement(new CurvePoint(2.71, 0.996635839593));
        addElement(new CurvePoint(2.72, 0.996735904184));
        addElement(new CurvePoint(2.73, 0.996833283723));
        addElement(new CurvePoint(2.74, 0.996928040781));
        addElement(new CurvePoint(2.75, 0.997020236765));
        addElement(new CurvePoint(2.76, 0.997109931924));
        addElement(new CurvePoint(2.77, 0.997197185367));
        addElement(new CurvePoint(2.78, 0.997282055077));
        addElement(new CurvePoint(2.79, 0.997364597922));
        addElement(new CurvePoint(2.8, 0.99744486967));
        addElement(new CurvePoint(2.81, 0.997522925001));
        addElement(new CurvePoint(2.82, 0.997598817526));
        addElement(new CurvePoint(2.83, 0.997672599793));
        addElement(new CurvePoint(2.84, 0.997744323308));
        addElement(new CurvePoint(2.85, 0.997814038545));
        addElement(new CurvePoint(2.86, 0.99788179496));
        addElement(new CurvePoint(2.87, 0.997947641005));
        addElement(new CurvePoint(2.88, 0.998011624145));
        addElement(new CurvePoint(2.89, 0.998073790868));
        addElement(new CurvePoint(2.9, 0.9981341867));
        addElement(new CurvePoint(2.91, 0.998192856219));
        addElement(new CurvePoint(2.92, 0.998249843071));
        addElement(new CurvePoint(2.93, 0.998305189981));
        addElement(new CurvePoint(2.94, 0.998358938766));
        addElement(new CurvePoint(2.95, 0.998411130353));
        addElement(new CurvePoint(2.96, 0.998461804788));
        addElement(new CurvePoint(2.97, 0.998511001255));
        addElement(new CurvePoint(2.98, 0.998558758083));
        addElement(new CurvePoint(2.99, 0.998605112765));
        addElement(new CurvePoint(3.0, 0.998650101968));
        addElement(new CurvePoint(3.01, 0.998693761551));
        addElement(new CurvePoint(3.02, 0.998736126572));
        addElement(new CurvePoint(3.03, 0.998777231306));
        addElement(new CurvePoint(3.04, 0.998817109257));
        addElement(new CurvePoint(3.05, 0.998855793169));
        addElement(new CurvePoint(3.06, 0.998893315043));
        addElement(new CurvePoint(3.07, 0.998929706145));
        addElement(new CurvePoint(3.08, 0.998964997025));
        addElement(new CurvePoint(3.09, 0.998999217523));
        addElement(new CurvePoint(3.1, 0.999032396787));
        addElement(new CurvePoint(3.11, 0.99906456328));
        addElement(new CurvePoint(3.12, 0.9990957448));
        addElement(new CurvePoint(3.13, 0.999125968484));
        addElement(new CurvePoint(3.14, 0.999155260827));
        addElement(new CurvePoint(3.15, 0.999183647687));
        addElement(new CurvePoint(3.16, 0.999211154306));
        addElement(new CurvePoint(3.17, 0.999237805312));
        addElement(new CurvePoint(3.18, 0.999263624738));
        addElement(new CurvePoint(3.19, 0.999288636031));
        addElement(new CurvePoint(3.2, 0.999312862062));
        addElement(new CurvePoint(3.21, 0.999336325139));
        addElement(new CurvePoint(3.22, 0.999359047016));
        addElement(new CurvePoint(3.23, 0.99938104891));
        addElement(new CurvePoint(3.24, 0.999402351502));
        addElement(new CurvePoint(3.25, 0.999422974958));
        addElement(new CurvePoint(3.26, 0.999442938931));
        addElement(new CurvePoint(3.27, 0.999462262578));
        addElement(new CurvePoint(3.28, 0.999480964567));
        addElement(new CurvePoint(3.29, 0.999499063086));
        addElement(new CurvePoint(3.3, 0.999516575858));
        addElement(new CurvePoint(3.31, 0.999533520144));
        addElement(new CurvePoint(3.32, 0.999549912759));
        addElement(new CurvePoint(3.33, 0.99956577008));
        addElement(new CurvePoint(3.34, 0.999581108051));
        addElement(new CurvePoint(3.35, 0.999595942198));
        addElement(new CurvePoint(3.36, 0.999610287637));
        addElement(new CurvePoint(3.37, 0.999624159082));
        addElement(new CurvePoint(3.38, 0.999637570851));
        addElement(new CurvePoint(3.39, 0.999650536882));
        addElement(new CurvePoint(3.4, 0.999663070734));
        addElement(new CurvePoint(3.41, 0.999675185603));
        addElement(new CurvePoint(3.42, 0.999686894321));
        addElement(new CurvePoint(3.43, 0.999698209375));
        addElement(new CurvePoint(3.44, 0.999709142907));
        addElement(new CurvePoint(3.45, 0.999719706723));
        addElement(new CurvePoint(3.46, 0.999729912306));
        addElement(new CurvePoint(3.47, 0.999739770818));
        addElement(new CurvePoint(3.48, 0.999749293109));
        addElement(new CurvePoint(3.49, 0.999758489726));
        addElement(new CurvePoint(3.5, 0.999767370921));
        addElement(new CurvePoint(3.51, 0.999775946653));
        addElement(new CurvePoint(3.52, 0.999784226601));
        addElement(new CurvePoint(3.53, 0.999792220167));
        addElement(new CurvePoint(3.54, 0.999799936484));
        addElement(new CurvePoint(3.55, 0.999807384424));
        addElement(new CurvePoint(3.56, 0.999814572603));
        addElement(new CurvePoint(3.57, 0.999821509386));
        addElement(new CurvePoint(3.58, 0.999828202896));
        addElement(new CurvePoint(3.59, 0.999834661019));
        addElement(new CurvePoint(3.6, 0.99984089141));
        addElement(new CurvePoint(3.61, 0.999846901497));
        addElement(new CurvePoint(3.62, 0.999852698492));
        addElement(new CurvePoint(3.63, 0.99985828939));
        addElement(new CurvePoint(3.64, 0.99986368098));
        addElement(new CurvePoint(3.65, 0.999868879846));
        addElement(new CurvePoint(3.66, 0.999873892376));
        addElement(new CurvePoint(3.67, 0.999878724766));
        addElement(new CurvePoint(3.68, 0.999883383023));
        addElement(new CurvePoint(3.69, 0.999887872974));
        addElement(new CurvePoint(3.7, 0.999892200267));
        addElement(new CurvePoint(3.71, 0.999896370376));
        addElement(new CurvePoint(3.72, 0.999900388611));
        addElement(new CurvePoint(3.73, 0.999904260115));
        addElement(new CurvePoint(3.74, 0.999907989873));
        addElement(new CurvePoint(3.75, 0.999911582715));
        addElement(new CurvePoint(3.76, 0.999915043322));
        addElement(new CurvePoint(3.77, 0.999918376226));
        addElement(new CurvePoint(3.78, 0.999921585821));
        addElement(new CurvePoint(3.79, 0.999924676358));
        addElement(new CurvePoint(3.8, 0.999927651956));
        addElement(new CurvePoint(3.81, 0.999930516604));
        addElement(new CurvePoint(3.82, 0.999933274163));
        addElement(new CurvePoint(3.83, 0.999935928371));
        addElement(new CurvePoint(3.84, 0.999938482845));
        addElement(new CurvePoint(3.85, 0.999940941088));
        addElement(new CurvePoint(3.86, 0.999943306487));
        addElement(new CurvePoint(3.87, 0.999945582323));
        addElement(new CurvePoint(3.88, 0.999947771768));
        addElement(new CurvePoint(3.89, 0.999949877889));
        addElement(new CurvePoint(3.9, 0.999951903656));
        addElement(new CurvePoint(3.91, 0.999953851939));
        addElement(new CurvePoint(3.92, 0.999955725516));
        addElement(new CurvePoint(3.93, 0.999957527069));
        addElement(new CurvePoint(3.94, 0.999959259195));
        addElement(new CurvePoint(3.95, 0.999960924403));
        addElement(new CurvePoint(3.96, 0.999962525118));
        addElement(new CurvePoint(3.97, 0.999964063684));
        addElement(new CurvePoint(3.98, 0.999965542366));
        addElement(new CurvePoint(3.99, 0.999966963352));
        addElement(new CurvePoint(4.0, 0.999968328758));
        addElement(new CurvePoint(4.01, 0.999969640626));
        addElement(new CurvePoint(4.02, 0.999970900929));
        addElement(new CurvePoint(4.03, 0.999972111574));
        addElement(new CurvePoint(4.04, 0.999973274399));
        addElement(new CurvePoint(4.05, 0.999974391184));
        addElement(new CurvePoint(4.06, 0.999975463642));
        addElement(new CurvePoint(4.07, 0.999976493431));
        addElement(new CurvePoint(4.08, 0.99997748215));
        addElement(new CurvePoint(4.09, 0.999978431341));
        addElement(new CurvePoint(4.1, 0.999979342493));
        addElement(new CurvePoint(4.11, 0.999980217044));
        addElement(new CurvePoint(4.12, 0.99998105638));
        addElement(new CurvePoint(4.13, 0.999981861838));
        addElement(new CurvePoint(4.14, 0.999982634709));
        addElement(new CurvePoint(4.15, 0.999983376236));
        addElement(new CurvePoint(4.16, 0.99998408762));
        addElement(new CurvePoint(4.17, 0.999984770018));
        addElement(new CurvePoint(4.18, 0.999985424545));
        addElement(new CurvePoint(4.19, 0.999986052277));
        addElement(new CurvePoint(4.2, 0.999986654251));
        addElement(new CurvePoint(4.21, 0.999987231466));
        addElement(new CurvePoint(4.22, 0.999987784884));
        addElement(new CurvePoint(4.23, 0.999988315434));
        addElement(new CurvePoint(4.24, 0.999988824011));
        addElement(new CurvePoint(4.25, 0.999989311474));
        addElement(new CurvePoint(4.26, 0.999989778655));
        addElement(new CurvePoint(4.27, 0.999990226352));
        addElement(new CurvePoint(4.28, 0.999990655334));
        addElement(new CurvePoint(4.29, 0.999991066344));
        addElement(new CurvePoint(4.3, 0.999991460095));
        addElement(new CurvePoint(4.31, 0.999991837273));
        addElement(new CurvePoint(4.32, 0.99999219854));
        addElement(new CurvePoint(4.33, 0.999992544533));
        addElement(new CurvePoint(4.34, 0.999992875864));
        addElement(new CurvePoint(4.35, 0.999993193123));
        addElement(new CurvePoint(4.36, 0.999993496878));
        addElement(new CurvePoint(4.37, 0.999993787673));
        addElement(new CurvePoint(4.38, 0.999994066035));
        addElement(new CurvePoint(4.39, 0.999994332467));
        addElement(new CurvePoint(4.4, 0.999994587456));
        addElement(new CurvePoint(4.41, 0.999994831469));
        addElement(new CurvePoint(4.42, 0.999995064955));
        addElement(new CurvePoint(4.43, 0.999995288346));
        addElement(new CurvePoint(4.44, 0.999995502056));
        addElement(new CurvePoint(4.45, 0.999995706486));
        addElement(new CurvePoint(4.46, 0.999995902017));
        addElement(new CurvePoint(4.47, 0.99999608902));
        addElement(new CurvePoint(4.48, 0.999996267848));
        addElement(new CurvePoint(4.49, 0.999996438841));
        addElement(new CurvePoint(4.5, 0.999996602327));
        addElement(new CurvePoint(4.51, 0.999996758619));
        addElement(new CurvePoint(4.52, 0.999996908018));
        addElement(new CurvePoint(4.53, 0.999997050816));
        addElement(new CurvePoint(4.54, 0.999997187289));
        addElement(new CurvePoint(4.55, 0.999997317704));
        addElement(new CurvePoint(4.56, 0.999997442319));
        addElement(new CurvePoint(4.57, 0.999997561379));
        addElement(new CurvePoint(4.58, 0.99999767512));
        addElement(new CurvePoint(4.59, 0.99999778377));
        addElement(new CurvePoint(4.6, 0.999997887545));
        addElement(new CurvePoint(4.61, 0.999997986655));
        addElement(new CurvePoint(4.62, 0.9999980813));
        addElement(new CurvePoint(4.63, 0.999998171671));
        addElement(new CurvePoint(4.64, 0.999998257954));
        addElement(new CurvePoint(4.65, 0.999998340325));
        addElement(new CurvePoint(4.66, 0.999998418953));
        addElement(new CurvePoint(4.67, 0.999998494001));
        addElement(new CurvePoint(4.68, 0.999998565625));
        addElement(new CurvePoint(4.69, 0.999998633975));
        addElement(new CurvePoint(4.7, 0.999998699193));
        addElement(new CurvePoint(4.71, 0.999998761416));
        addElement(new CurvePoint(4.72, 0.999998820777));
        addElement(new CurvePoint(4.73, 0.999998877401));
        addElement(new CurvePoint(4.74, 0.999998931409));
        addElement(new CurvePoint(4.75, 0.999998982917));
        addElement(new CurvePoint(4.76, 0.999999032035));
        addElement(new CurvePoint(4.77, 0.99999907887));
        addElement(new CurvePoint(4.78, 0.999999123524));
        addElement(new CurvePoint(4.79, 0.999999166093));
        addElement(new CurvePoint(4.8, 0.999999206672));
        addElement(new CurvePoint(4.81, 0.999999245349));
        addElement(new CurvePoint(4.82, 0.999999282209));
        addElement(new CurvePoint(4.83, 0.999999317335));
        addElement(new CurvePoint(4.84, 0.999999350804));
        addElement(new CurvePoint(4.85, 0.999999382693));
        addElement(new CurvePoint(4.86, 0.999999413071));
        addElement(new CurvePoint(4.87, 0.999999442009));
        addElement(new CurvePoint(4.88, 0.999999469571));
        addElement(new CurvePoint(4.89, 0.99999949582));
        addElement(new CurvePoint(4.9, 0.999999520817));
        addElement(new CurvePoint(4.91, 0.999999544618));
        addElement(new CurvePoint(4.92, 0.999999567279));
        addElement(new CurvePoint(4.93, 0.999999588852));
        addElement(new CurvePoint(4.94, 0.999999609387));
        addElement(new CurvePoint(4.95, 0.999999628933));
        addElement(new CurvePoint(4.96, 0.999999647534));
        addElement(new CurvePoint(4.97, 0.999999665235));
        addElement(new CurvePoint(4.98, 0.999999682079));
        addElement(new CurvePoint(4.99, 0.999999698104));
        addElement(new CurvePoint(5.0, 0.999999713348));
        addElement(new CurvePoint(5.01, 0.99999972785));
        addElement(new CurvePoint(5.02, 0.999999741643));
        addElement(new CurvePoint(5.03, 0.99999975476));
        addElement(new CurvePoint(5.04, 0.999999767234));
        addElement(new CurvePoint(5.05, 0.999999779095));
        addElement(new CurvePoint(5.06, 0.999999790372));
        addElement(new CurvePoint(5.07, 0.999999801092));
        addElement(new CurvePoint(5.08, 0.999999811283));
        addElement(new CurvePoint(5.09, 0.999999820968));
        addElement(new CurvePoint(5.1, 0.999999830173));
        addElement(new CurvePoint(5.11, 0.999999838921));
        addElement(new CurvePoint(5.12, 0.999999847232));
        addElement(new CurvePoint(5.13, 0.999999855129));
        addElement(new CurvePoint(5.14, 0.999999862631));
        addElement(new CurvePoint(5.15, 0.999999869757));
        addElement(new CurvePoint(5.16, 0.999999876525));
        addElement(new CurvePoint(5.17, 0.999999882953));
        addElement(new CurvePoint(5.18, 0.999999889057));
        addElement(new CurvePoint(5.19, 0.999999894853));
        addElement(new CurvePoint(5.2, 0.999999900356));
        addElement(new CurvePoint(5.21, 0.99999990558));
        addElement(new CurvePoint(5.22, 0.999999910538));
        addElement(new CurvePoint(5.23, 0.999999915245));
        addElement(new CurvePoint(5.24, 0.999999919712));
        addElement(new CurvePoint(5.25, 0.99999992395));
        addElement(new CurvePoint(5.26, 0.999999927972));
        addElement(new CurvePoint(5.27, 0.999999931788));
        addElement(new CurvePoint(5.28, 0.999999935408));
        addElement(new CurvePoint(5.29, 0.999999938842));
        addElement(new CurvePoint(5.3, 0.999999942099));
        addElement(new CurvePoint(5.31, 0.999999945187));
        addElement(new CurvePoint(5.32, 0.999999948116));
        addElement(new CurvePoint(5.33, 0.999999950894));
        addElement(new CurvePoint(5.34, 0.999999953527));
        addElement(new CurvePoint(5.35, 0.999999956023));
        addElement(new CurvePoint(5.36, 0.999999958389));
        addElement(new CurvePoint(5.37, 0.999999960632));
        addElement(new CurvePoint(5.38, 0.999999962757));
        addElement(new CurvePoint(5.39, 0.999999964771));
        addElement(new CurvePoint(5.4, 0.99999996668));
        addElement(new CurvePoint(5.41, 0.999999968488));
        addElement(new CurvePoint(5.42, 0.9999999702));
        addElement(new CurvePoint(5.43, 0.999999971823));
        addElement(new CurvePoint(5.44, 0.99999997336));
        addElement(new CurvePoint(5.45, 0.999999974815));
        addElement(new CurvePoint(5.46, 0.999999976193));
        addElement(new CurvePoint(5.47, 0.999999977498));
        addElement(new CurvePoint(5.48, 0.999999978734));
        addElement(new CurvePoint(5.49, 0.999999979903));
        addElement(new CurvePoint(5.5, 0.99999998101));
        addElement(new CurvePoint(5.51, 0.999999982058));
        addElement(new CurvePoint(5.52, 0.99999998305));
        addElement(new CurvePoint(5.53, 0.999999983988));
        addElement(new CurvePoint(5.54, 0.999999984876));
        addElement(new CurvePoint(5.55, 0.999999985717));
        addElement(new CurvePoint(5.56, 0.999999986511));
        addElement(new CurvePoint(5.57, 0.999999987263));
        addElement(new CurvePoint(5.58, 0.999999987974));
        addElement(new CurvePoint(5.59, 0.999999988647));
        addElement(new CurvePoint(5.6, 0.999999989282));
        addElement(new CurvePoint(5.61, 0.999999989884));
        addElement(new CurvePoint(5.62, 0.999999990452));
        addElement(new CurvePoint(5.63, 0.99999999099));
        addElement(new CurvePoint(5.64, 0.999999991497));
        addElement(new CurvePoint(5.65, 0.999999991978));
        addElement(new CurvePoint(5.66, 0.999999992431));
        addElement(new CurvePoint(5.67, 0.99999999286));
        addElement(new CurvePoint(5.68, 0.999999993265));
        addElement(new CurvePoint(5.69, 0.999999993648));
        addElement(new CurvePoint(5.7, 0.99999999401));
        addElement(new CurvePoint(5.71, 0.999999994351));
        addElement(new CurvePoint(5.72, 0.999999994674));
        addElement(new CurvePoint(5.73, 0.999999994978));
        addElement(new CurvePoint(5.74, 0.999999995266));
        addElement(new CurvePoint(5.75, 0.999999995538));
        addElement(new CurvePoint(5.76, 0.999999995794));
        addElement(new CurvePoint(5.77, 0.999999996036));
        addElement(new CurvePoint(5.78, 0.999999996265));
        addElement(new CurvePoint(5.79, 0.999999996481));
        addElement(new CurvePoint(5.8, 0.999999996684));
        addElement(new CurvePoint(5.81, 0.999999996876));
        addElement(new CurvePoint(5.82, 0.999999997058));
        addElement(new CurvePoint(5.83, 0.999999997229));
        addElement(new CurvePoint(5.84, 0.99999999739));
        addElement(new CurvePoint(5.85, 0.999999997542));
        addElement(new CurvePoint(5.86, 0.999999997686));
        addElement(new CurvePoint(5.87, 0.999999997821));
        addElement(new CurvePoint(5.88, 0.999999997949));
        addElement(new CurvePoint(5.89, 0.999999998069));
        addElement(new CurvePoint(5.9, 0.999999998182));
        addElement(new CurvePoint(5.91, 0.999999998289));
        addElement(new CurvePoint(5.92, 0.99999999839));
        addElement(new CurvePoint(5.93, 0.999999998485));
        addElement(new CurvePoint(5.94, 0.999999998575));
        addElement(new CurvePoint(5.95, 0.999999998659));
        addElement(new CurvePoint(5.96, 0.999999998739));
        addElement(new CurvePoint(5.97, 0.999999998814));
        addElement(new CurvePoint(5.98, 0.999999998884));
        addElement(new CurvePoint(5.99, 0.999999998951));
        addElement(new CurvePoint(6.0, 0.999999999013));
        addElement(new CurvePoint(6.01, 0.999999999072));
        addElement(new CurvePoint(6.02, 0.999999999128));
        addElement(new CurvePoint(6.03, 0.99999999918));
        addElement(new CurvePoint(6.04, 0.999999999229));
        addElement(new CurvePoint(6.05, 0.999999999276));
        addElement(new CurvePoint(6.06, 0.999999999319));
        addElement(new CurvePoint(6.07, 0.99999999936));
        addElement(new CurvePoint(6.08, 0.999999999399));
        addElement(new CurvePoint(6.09, 0.999999999435));
        addElement(new CurvePoint(6.1, 0.99999999947));
        addElement(new CurvePoint(6.11, 0.999999999502));
        addElement(new CurvePoint(6.12, 0.999999999532));
        addElement(new CurvePoint(6.13, 0.999999999561));
        addElement(new CurvePoint(6.14, 0.999999999587));
        addElement(new CurvePoint(6.15, 0.999999999613));
        addElement(new CurvePoint(6.16, 0.999999999636));
        addElement(new CurvePoint(6.17, 0.999999999659));
        addElement(new CurvePoint(6.18, 0.999999999679));
        addElement(new CurvePoint(6.19, 0.999999999699));
        addElement(new CurvePoint(6.2, 0.999999999718));
        addElement(new CurvePoint(6.21, 0.999999999735));
        addElement(new CurvePoint(6.22, 0.999999999751));
        addElement(new CurvePoint(6.23, 0.999999999767));
        addElement(new CurvePoint(6.24, 0.999999999781));
        addElement(new CurvePoint(6.25, 0.999999999795));
        addElement(new CurvePoint(6.26, 0.999999999808));
        addElement(new CurvePoint(6.27, 0.999999999819));
        addElement(new CurvePoint(6.28, 0.999999999831));
        addElement(new CurvePoint(6.29, 0.999999999841));
        addElement(new CurvePoint(6.3, 0.999999999851));
        addElement(new CurvePoint(6.31, 0.99999999986));
        addElement(new CurvePoint(6.32, 0.999999999869));
        addElement(new CurvePoint(6.33, 0.999999999877));
        addElement(new CurvePoint(6.34, 0.999999999885));
        addElement(new CurvePoint(6.35, 0.999999999892));
        addElement(new CurvePoint(6.36, 0.999999999899));
        addElement(new CurvePoint(6.37, 0.999999999905));
        addElement(new CurvePoint(6.38, 0.999999999911));
        addElement(new CurvePoint(6.39, 0.999999999917));
        addElement(new CurvePoint(6.4, 0.999999999922));
        addElement(new CurvePoint(6.41, 0.999999999927));
        addElement(new CurvePoint(6.42, 0.999999999932));
        addElement(new CurvePoint(6.43, 0.999999999936));
        addElement(new CurvePoint(6.44, 0.99999999994));
        addElement(new CurvePoint(6.45, 0.999999999944));
        addElement(new CurvePoint(6.46, 0.999999999948));
        addElement(new CurvePoint(6.47, 0.999999999951));
        addElement(new CurvePoint(6.48, 0.999999999954));
        addElement(new CurvePoint(6.49, 0.999999999957));
        addElement(new CurvePoint(6.5, 0.99999999996));
        addElement(new CurvePoint(6.51, 0.999999999962));
        addElement(new CurvePoint(6.52, 0.999999999965));
        addElement(new CurvePoint(6.53, 0.999999999967));
        addElement(new CurvePoint(6.54, 0.999999999969));
        addElement(new CurvePoint(6.55, 0.999999999971));
        addElement(new CurvePoint(6.56, 0.999999999973));
        addElement(new CurvePoint(6.57, 0.999999999975));
        addElement(new CurvePoint(6.58, 0.999999999976));
        addElement(new CurvePoint(6.59, 0.999999999978));
        addElement(new CurvePoint(6.6, 0.999999999979));
        addElement(new CurvePoint(6.61, 0.999999999981));
        addElement(new CurvePoint(6.62, 0.999999999982));
        addElement(new CurvePoint(6.63, 0.999999999983));
        addElement(new CurvePoint(6.64, 0.999999999984));
        addElement(new CurvePoint(6.65, 0.999999999985));
        addElement(new CurvePoint(6.66, 0.999999999986));
        addElement(new CurvePoint(6.67, 0.999999999987));
        addElement(new CurvePoint(6.68, 0.999999999988));
        addElement(new CurvePoint(6.69, 0.999999999989));
        addElement(new CurvePoint(6.7, 0.99999999999));
        addElement(new CurvePoint(6.72, 0.999999999991));
        addElement(new CurvePoint(6.73, 0.999999999992));
        addElement(new CurvePoint(6.75, 0.999999999993));
        addElement(new CurvePoint(6.77, 0.999999999994));
        addElement(new CurvePoint(6.8, 0.999999999995));
        addElement(new CurvePoint(6.82, 0.999999999995));
        addElement(new CurvePoint(6.83, 0.999999999996));
        addElement(new CurvePoint(6.86, 0.999999999997));
        addElement(new CurvePoint(6.91, 0.999999999998));
        addElement(new CurvePoint(6.98, 0.999999999999));
        addElement(new CurvePoint(7.14, 1.0));
    }

    // overridden to handle negative x

    public double getValueOf(double x)
    {
        if (x > 0.0)
        {
            return super.getValueOf(x);
        }
        else
        {
            return 1.0 - super.getValueOf(-x);
        }
    }
}

class Test
{
    // given x, compute the Cumulative Normal function using two methods
    // (N1 uses polynomial approximation, N2 uses linear interpolation)
    // then performs reverse compuation using methods (using Newton-Raphson
    // and linear solver).

    public static void main(String[] arg) throws Exception
    {
        // polynomial approximation version

        CumulativeNormal N1 = new CumulativeNormal();

        // linear interpolation version

        CumulativeNormal2 N2 = new CumulativeNormal2();

        DataInputStream in = new DataInputStream(System.in);

        System.out.println("Ready");

        for (;;)
        {
            String s = in.readLine();

            double d = (Double.valueOf(s)).doubleValue();

            // value using polynomial approximation

            double n1 = N1.getValueOf(d);

            // value using linear interpolation

            double n2 = N2.getValueOf(d);

            // inverse normal using Newton-Raphson

            double x = CurveSolver.useNewtonRaphson(N1, 0.0, n1, 0.0000001, 1000);

            // inverse normal using linear solver
            // note that N2 only has points for positive x

            double xx = 0.0;

            if (n2 >= 0.5)
            {
                xx = CurveSolver.useLinear(N2, n2, 0.0, 10.0);
            }
            else
            {
                xx = - CurveSolver.useLinear(N2, 1.0 - n2, 0.0, 10.0);
            }

            // outputs

            System.out.println("in: " + d);

            System.out.println("N1: " + n1);
            System.out.println("N2: " + n2);

            System.out.println(" x: " + x);
            System.out.println("xx: " + xx);
        }
    }
}






