// LinearSegmentedCurve (With Linear Interpolation)

// Copyright (C) 1999 by Makoto Nagata, MicroNova <mnagata@micronova.com>.  All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
// OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
// OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
// SUCH DAMAGE.
//
// Visit http://www.micronova.com for updates

package com.micronova.math;

/**

   A SegmentedCurve with linear interpolation.  Given N boundary CurvePoints {(x[0], y[0]), ..., (x[N-1], y[N-1])}, the curve value f(x) is defined as follows:<BR>
   <ul>
   <li>x[0] if x < x[0]</li>
   <li>y[k] + (y[k+1] - y[k]) * (x - x[k]) / (x[k+1] - x[k]) if x[k] <= x < x[k+1] (k = 1, 2, ..., N-1)</li>
   <li>x[N-1] if x >= x[N-1]</li>
   </ul>
   (f(x) = 0 if there is no boundary CurvePoints).

   * @author Makoto Nagata, MicroNova
   * @version 1.0

   */

public class LinearSegmentedCurve extends SegmentedCurve
{
    public double getValueInSegment(double x, int index)
    {
        // default is linear interpolation

        if (index < 0)
        {
            return 0.0;
        }
        else if (index == 0)
        {
            return ((CurvePoint)elementAt(0)).y;
        }
        else if (index == size())
        {
            return ((CurvePoint)elementAt(index - 1)).y;
        }
        else
        {
            CurvePoint lowPoint = ((CurvePoint)elementAt(index - 1));
            CurvePoint highPoint = ((CurvePoint)elementAt(index));

            double l = lowPoint.x;
            double lv = lowPoint.y;

            double h = highPoint.x;
            double hv = highPoint.y;

            return (l == h) ? lv : (lv + (hv - lv) * (x - l) / (h - l));
        }                
    }
}
