// Segmented Curve

// Copyright (C) 1999 by Makoto Nagata, MicroNova <mnagata@micronova.com>.  All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
// OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
// OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
// SUCH DAMAGE.
//
// Visit http://www.micronova.com for updates

package com.micronova.math;

import netscape.util.*;
import com.micronova.util.*;

/**

   A SegmentedCurve is a curve that consists of multiple segments defined by an ordered sequence of boundary CurvePoints (e.g., a linearly interpolated curve).<BR>
   An ordered  sequence of N boundary CurvePoints {(x[0], y[0]), (x[1], y[1]), ..., (x[N-1], y[N-1])} (where x[0] < x[1] < ... < x[N-1])
   defines (N+1) segments as follows: <BR>
   <ul>
   <li>segment 0: (-infinity, x[0])</li>
   <li>segment k (k = 1, 2, ..., N-1): [x[k - 1], x[k])</li>
   <li>segment N: [x[N-1], +infinity)
   </ul>

   * @version 1.0
   * @author Makoto Nagata, MicroNova
   * @see com.micronova.math.CurvePoint
   * @see com.micronova.util.SortedVector

*/

public abstract class SegmentedCurve extends SortedVector implements Curve
{
    /** Returns the index of the segment to which a given value x belongs.  It returns -1 if there is no boundary points.  */

    public int getSegmentIndex(double x)
    {
        return getSegmentIndex(new CurvePoint(x, 0.0));
    };

    /** Defines the value for a given point x in index-th segment.  This is abstract. */

    public abstract double getValueInSegment(double x, int index);

    /** The value of this Curve. */

    public double getValueOf(double x)
    {
        return getValueInSegment(x, getSegmentIndex(x));
    }
}





